@@ -14,16 +14,18 @@
 # ==============================================================================
 """API of tf2jax."""
 
+from tf2jax._src.config import get_config
+from tf2jax._src.config import override_config
+from tf2jax._src.config import update_config
+
+from tf2jax._src.tf2jax import AnnotatedFunction
+
 from tf2jax._src.tf2jax import convert
 from tf2jax._src.tf2jax import convert_from_restored
 from tf2jax._src.tf2jax import convert_functional
 from tf2jax._src.tf2jax import convert_functional_from_restored
 
-from tf2jax._src.tf2jax import get_config
-from tf2jax._src.tf2jax import override_config
-from tf2jax._src.tf2jax import update_config
-
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
 #  _________________________________________
 # / Please don't use symbols in `_src` they \
