@@ -23,6 +23,7 @@ import jax
 import numpy as np
 
 import tensorflow as tf
+from tf2jax._src import ops
 from tf2jax._src import tf2jax
 import tree
 
@@ -38,6 +39,11 @@ def _nullcontext(enter_result=None):
 
 class OpsTest(tf.test.TestCase, parameterized.TestCase):
 
+  def test_get_unsupported(self):
+    unsupported = ops.get_unsupported_operations(
+        ["Add", "Relu", "NotAnOp", "Blah", "Relu"])
+    self.assertEqual(unsupported, {"NotAnOp", "Blah"})
+
   def _assert_if_jitted(self, err):
     jitted = self.variant.type == chex.ChexVariantType.WITH_JIT
     return self.assertRaises(err) if jitted else _nullcontext()
@@ -290,18 +296,25 @@ class OpsTest(tf.test.TestCase, parameterized.TestCase):
   @parameterized.named_parameters(
       chex.params_product(
           (("NHWC", "NHWC"), ("NCHW", "NCHW")),
+          (
+              ("three_dims", (32, 16, 8)),
+              ("four_dims", (3, 32, 16, 8)),
+              ("five_dims", (2, 3, 32, 16, 8)),
+          ),
           named=True,
       ))
-  def test_bias_add(self, data_format):
+  def test_bias_add(self, data_format, input_shape):
     np.random.seed(42)
 
-    inputs = np.random.normal(size=(10, 32, 16, 8)).astype(np.float32)
-    bias = np.linspace(-1., 1., 8).astype(np.float32)
-
     if data_format == "NCHW":
-      inputs = np.transpose(inputs, [0, 3, 1, 2])
+      nchannels = input_shape[1]
+    elif data_format == "NHWC":
+      nchannels = input_shape[-1]
     else:
-      assert data_format == "NHWC"
+      raise ValueError(f"Unsupported format {data_format}")
+
+    inputs = np.random.normal(size=input_shape).astype(np.float32)
+    bias = bias = np.linspace(-1., 1., nchannels).astype(np.float32)
 
     def pool(x, b):
       return tf.raw_ops.BiasAdd(value=x, bias=b, data_format=data_format)
@@ -602,6 +615,7 @@ class OpsTest(tf.test.TestCase, parameterized.TestCase):
       chex.params_product(
           (("inference", False), ("training", True)),
           (
+              ("FusedBatchNorm", "FusedBatchNorm"),
               ("FusedBatchNormV2", "FusedBatchNormV2"),
               ("FusedBatchNormV3", "FusedBatchNormV3"),
           ),
@@ -977,7 +991,7 @@ class OpsTest(tf.test.TestCase, parameterized.TestCase):
 
     @tf.function
     def prevent(x):
-      return tf.raw_ops.PreventGradient(input=x, message=error_message)
+      return tf.raw_ops.PreventGradient(input=x * x, message=error_message)
 
     np_x = np.array(3.14, dtype=np.float32)
     tf_x = tf.constant(np_x)
@@ -992,10 +1006,18 @@ class OpsTest(tf.test.TestCase, parameterized.TestCase):
     jax_func = self.variant(jax_func)
     jax_y = jax_func(np_x)
 
+    self.assertAllClose(tf_y, jax_y)
     with self.assertRaisesRegex(LookupError, error_message):
       jax.grad(jax_func)(np_x)
 
-    self.assertAllClose(tf_y, jax_y)
+    with tf2jax.config.override_config("raise_on_prevent_gradient", False):
+      jax_func = tf2jax.convert_functional(prevent, np.zeros_like(np_x))
+      jax_func = self.variant(jax_func)
+      jax_y = jax_func(np_x)
+      self.assertAllClose(tf_y, jax_y)
+
+      jax_grad = jax.grad(jax_func)(np_x)
+      self.assertAllClose(np_x * 2, jax_grad)
 
   @chex.variants(with_jit=True, without_jit=True)
   def test_pad(self):
@@ -1022,6 +1044,19 @@ class OpsTest(tf.test.TestCase, parameterized.TestCase):
       return tf.zeros(prod(inputs))
     self._test_convert(prod_static, [])
 
+  @chex.variants(with_jit=True, without_jit=True)
+  def test_rank(self):
+    inputs = np.array(np.reshape(range(24), (4, 3, 2)), dtype=np.int32)
+
+    def rank(xs):
+      return tf.raw_ops.Rank(input=xs)
+    self._test_convert(rank, inputs)
+
+    # Check static inputs result in static outputs.
+    def rank_static():
+      return tf.zeros(rank(inputs))
+    self._test_convert(rank_static, [])
+
   @chex.variants(with_jit=True, without_jit=True)
   def test_squeeze(self):
     inputs, dims = np.array([[[42], [47]]]), (0, 2)
@@ -1578,6 +1613,19 @@ class OpsTest(tf.test.TestCase, parameterized.TestCase):
     with self.assertRaisesRegex(ValueError, "Some updated parameters are lost"):
       self._test_convert(while_loop, inputs, functional=False)
 
+  @chex.variants(with_jit=True, without_jit=True)
+  def test_while_captured_static_args(self):
+    # This can still fail if output_size is an argument to cond and body.
+    output_size = tf.constant([10, 5])
+    cond = lambda v, i: tf.less(i, 10)
+    body = lambda v, i: (v + tf.ones(output_size, tf.float32), tf.add(i, 1))
+    step = tf.constant(0)
+
+    @tf.function
+    def while_loop(x):
+      return tf.while_loop(cond, body, [x, step])
+    self._test_convert(while_loop, np.zeros(output_size, np.float32))
+
   @chex.variants(with_jit=True, without_jit=True)
   def test_assign_side_effect(self):
     inputs = np.array([42, 47], dtype=np.float32)
